<?php
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Wonder_Grid_Widget extends Widget_Base {

    public function get_name() {
        return 'wonder-grid-widget';
    }

    public function get_title() {
        return esc_html__( 'Wonder Grid', 'wonder-grid' );
    }

    public function get_icon() {
        return 'eicon-posts-grid';
    }

    public function get_categories() {
        return array( 'wonder-grid' );
    }

    protected function register_controls() {


        $this->start_controls_section(
            'section_project_layout',
            [
                'label' => esc_html__( 'Layout', 'wonder-grid' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'columns', [
                'label' => esc_html__( 'Columns', 'wonder-grid' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'show_label' => true,
                'default' => '3',
                'options' => [
                    '2' => esc_html__( 'Grid: 2 Columns', 'wonder-grid' ),
                    '3' => esc_html__( 'Grid: 3 Columns', 'wonder-grid' ),
                    '4' => esc_html__( 'Grid: 4 Columns', 'wonder-grid' ),
                    '5' => esc_html__( 'Grid: 5 Columns', 'wonder-grid' )
                ]
            ]
        );

        $this->add_control(
            'title_position', [
                'label' => esc_html__( 'Title Position', 'wonder-grid' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'show_label' => true,
                'default' => 'outside',
                'options' => [
                    'outside' => esc_html__( 'Outside The Box', 'wonder-grid' ),
                    'inside' => esc_html__( 'Inside The Box', 'wonder-grid' ),
                ]
            ]
        );

        $this->add_control(
            'hover_animation', [
                'label' => esc_html__( 'Hover Animation', 'wonder-grid' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'show_label' => true,
                'default' => 'no-animation',
                'options' => [
                    'no-animation' => esc_html__( 'No Animation', 'wonder-grid' ),
                    'zoom-in' => esc_html__( 'Zoom In', 'wonder-grid' ),
                    'zoom-out' => esc_html__( 'Zoom Out', 'wonder-grid' ),
                    'shine' => esc_html__( 'Shine', 'wonder-grid' ),
                    'circle' => esc_html__( 'Circle', 'wonder-grid' ),
                    'inner-border' => esc_html__( 'Inner Border', 'wonder-grid' ),
                    'flash' => esc_html__( 'Flash', 'wonder-grid' ),
                    'brightness' => esc_html__( 'Brightness', 'wonder-grid' )
                ]
            ]
        );

        $this->add_control(
            'filter',
            [
                'label' => esc_html__( 'Categories Filter', 'wonder-grid' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'wonder-grid' ),
                'label_off' => esc_html__( 'No', 'wonder-grid' ),
                'return_value' => '1',
                'default' => '0'
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_project_data',
            [
                'label' => esc_html__( 'Data', 'wonder-grid' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'pagination',
            [
                'label' => esc_html__( 'Enable Pagination', 'wonder-grid' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'wonder-grid' ),
                'label_off' => esc_html__( 'No', 'wonder-grid' ),
                'return_value' => '1',
                'default' => '0'
            ]
        );

        $this->add_control(
            'infinite',
            [
                'label' => esc_html__( 'Enable Infinite Scroll', 'wonder-grid' ),
                'description' => esc_html__( 'Loading more project items dynamically while scrolling down.', 'wonder-grid' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'wonder-grid' ),
                'label_off' => esc_html__( 'No', 'wonder-grid' ),
                'return_value' => '1',
                'default' => '0',
                'condition' => [
                    'pagination' => '1',
                ],
            ]
        );

        $this->add_control(
            'number',
            [
                'type' => Controls_Manager::NUMBER,
                'label' => esc_html__( 'Number of Items Per Page', 'wonder-grid' ),
                'min' => 2,
                'max' => 100,
                'step' => 1,
                'default' => 9
            ]
        );

        $this->add_control(
            'orderby', [
                'label' => esc_html__( 'Order By', 'wonder-grid' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'show_label' => true,
                'default' => 'date',
                'options' => [
                    'date' => esc_html__( 'Publish Date', 'wonder-grid' ),
                    'rand' => esc_html__( 'Random', 'wonder-grid' ),
                ]
            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__( 'Order By', 'wonder-grid' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'show_label' => true,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__( 'DESC', 'wonder-grid' ),
                    'asc' => esc_html__( 'ASC', 'wonder-grid' ),
                ]
            ]
        );

        $this->add_control(
            'categories', [
                'label' => esc_html__( 'Categories', 'wonder-grid' ),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'show_label' => true,
                'default' => '',
                'multiple' => true,
                'options' => wg_taxonomy_list()
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_project_grid_style',
            [
                'label' => esc_html__( 'Grid View', 'wonder-grid' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(

            'outside_title_color',
            [
                'type' => Controls_Manager::COLOR,
                'label' => esc_html__( 'Title Color', 'wonder-grid' ),
                'selectors' => [
                    '{{WRAPPER}} .wonder-grid-container .wg-project-item .wg_title a' => 'color: {{VALUE}};',
                ],
                'description'  =>  esc_html__( 'Change the title color which outside the box.', 'wonder-grid' ),
                'default' => '',
                'condition' => [
                    'title_position' => 'outside',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'outside_title_typography',
                'label' => esc_html__( 'Title Typography', 'wonder-grid' ),
                'scheme' => Typography::TYPOGRAPHY_2,
                'selector' => '{{WRAPPER}} .wonder-grid-container .wg-project-item .wg_title',
                'condition' => [
                    'title_position' => 'outside',
                ],
            ]
        );

        $this->add_control(

            'outside_category_color',
            [
                'type' => Controls_Manager::COLOR,
                'label' => esc_html__( 'Category Text Color', 'wonder-grid' ),
                'selectors' => [
                    '{{WRAPPER}} .wonder-grid-container .wg-project-item .wg-taxonomy' => 'color: {{VALUE}};',
                ],
                'description'  =>  esc_html__( 'Change the category text color which outside the box.', 'wonder-grid' ),
                'default' => '',
                'condition' => [
                    'title_position' => 'outside',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'outside_category_typography',
                'label' => esc_html__( 'Category Text Typography', 'wonder-grid' ),
                'scheme' => Typography::TYPOGRAPHY_2,
                'selector' => '{{WRAPPER}} .wonder-grid-container .wg-project-item .wg-taxonomy',
                'condition' => [
                    'title_position' => 'outside',
                ],
            ]
        );

        $this->add_control(

            'inside_title_color',
            [
                'type' => Controls_Manager::COLOR,
                'label' => esc_html__( 'Title Color', 'wonder-grid' ),
                'selectors' => [
                    '{{WRAPPER}} .wonder-grid-container .wg-project-item .project-thumbnail .wg_item_info .wg_title a' => 'color: {{VALUE}};',
                ],
                'description'  =>  esc_html__( 'Change the title color which inside the box.', 'wonder-grid' ),
                'default' => '',
                'condition' => [
                    'title_position' => 'inside',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'inside_title_typography',
                'label' => esc_html__( 'Title Typography', 'wonder-grid' ),
                'scheme' => Typography::TYPOGRAPHY_2,
                'selector' => '{{WRAPPER}} .wonder-grid-container .wg-project-item .project-thumbnail .wg_item_info .wg_title',
                'condition' => [
                    'title_position' => 'inside',
                ],
            ]
        );

        $this->add_control(

            'inside_category_color',
            [
                'type' => Controls_Manager::COLOR,
                'label' => esc_html__( 'Category Text Color', 'wonder-grid' ),
                'selectors' => [
                    '{{WRAPPER}} .wonder-grid-container .wg-project-item .project-thumbnail .wg_item_info .wg-taxonomy' => 'color: {{VALUE}};',
                ],
                'description'  =>  esc_html__( 'Change the category text color which inside the box.', 'wonder-grid' ),
                'default' => '#fff',
                'condition' => [
                    'title_position' => 'inside',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'inside_category_typography',
                'label' => esc_html__( 'Category Text Typography', 'wonder-grid' ),
                'scheme' => Typography::TYPOGRAPHY_2,
                'selector' => '{{WRAPPER}} .wonder-grid-container .wg-project-item .project-thumbnail .wg_item_info .wg-taxonomy',
                'condition' => [
                    'title_position' => 'inside',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $data = (array)$this->get_settings();
        $data['id'] = $this->get_id();

        ob_start();
        wg_load_template( self::get_name(), '', (object)$data );
        // Don't delete the following codes
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
            echo '<script>window.WG.grid();</script>';
        }
        echo ob_get_clean();
    }

    protected function content_template() {

    }

}
