<?php
/**
 * Hook in and register a metabox to handle a theme options page and adds a menu item.
 */
if( ! function_exists( 'wg_options_metabox' ) ) {
	function wg_options_metabox() {

		do_action('wonder_grid/options_tabs_start');

		/**
		 * Template
		 */
		$args = array(
			'id'           => 'wonder_grid',
			'title'        => esc_html__( 'Settings', 'wonder_grid' ),
			'object_types' => array( 'options-page' ),
			'option_key'   => 'wonder-grid',
			'parent_slug'  => 'edit.php?post_type=wonder-grid',
			'tab_group'    => 'wg_tabs',
			'tab_title'    => 'General',
		);
		
		// 'tab_group' property is supported in > 2.4.0.
		if ( version_compare( CMB2_VERSION, '2.4.0' ) ) {
			$args['display_cb'] = 'wg_options_display_with_tabs';
		}
		
		$wg_options = new_cmb2_box( $args );

		$wg_options->add_field( array(
			'name'    => 'Custom Post Type',
			'id'      => 'custom_post_type',
			'type'    => 'title',
			'desc'    => __( 'After you change the following slug settings, you may have to go to <a href=" ' . admin_url( 'options-permalink.php' ) . ' " target="_blank">Settings > Permalink</a>, save the permalink setting once more.', 'wonder-grid' ),
		) );

		$wg_options->add_field( array(
			'name'    => esc_html__( 'Post Type Slug', 'wonder-grid' ),
			'id'      => 'post_type_slug',
			'desc'    => __( 'the post type slug will be displayed in the post URL, e.g. https://domain.com/<strong style="color: red;">project</strong>/xxxx', 'wonder-grid' ),
			'type'    => 'text',
			'default' => 'project'
		) );

		$wg_options->add_field( array(
			'name'    => esc_html__( 'Taxomony Slug', 'wonder-grid' ),
			'id'      => 'taxonomy_slug',
			'desc'    => __( 'the taxonomy slug will be displayed in the project type page URL, e.g. https://domain.com/<strong style="color: red;">project-type</strong>/xxxx', 'wonder-grid' ),
			'type'    => 'text',
			'default' => 'project-type'
		) );


		$wg_options->add_field( array(
			'name'    => 'Single Post',
			'id'      => 'single_post',
			'type'    => 'title'
		) );

		$wg_options->add_field( array(
			'name'    => esc_html__( 'Enable Sticky Content', 'wonder-grid' ),
			'id'      => 'sticky_content',
			'desc'    => esc_html__('Stick the content when scrolling down the page.', 'wonder-grid'),
			'type'    => 'switch',
			'value'   => false,
			'active_value' => true
		) );

		$wg_options->add_field( array(
			'name'    => esc_html__( 'Enable Previous/Next Post', 'wonder-grid' ),
			'id'      => 'prev_next_post',
			'desc'    => esc_html__('Display the previous & next post at the bottom of the single post.', 'wonder-grid'),
			'type'    => 'switch',
			'value'   => true,
			'active_value' => true
		) );

		do_action('wonder_grid/options_tabs_end');


	}
	add_action( 'cmb2_admin_init', 'wg_options_metabox' );
}

/**
 * A CMB2 options-page display callback override which adds tab navigation among
 * CMB2 options pages which share this same display callback.
 *
 * @param CMB2_Options_Hookup $cmb_options The CMB2_Options_Hookup object.
 */
if( ! function_exists( 'wg_options_display_with_tabs' ) ) {
	function wg_options_display_with_tabs( $cmb_options ) {
		$tabs = wg_options_tabs( $cmb_options );
		?>
		<div class="wrap cmb2-options-page option-<?php echo $cmb_options->option_key; ?>">

			<h2 class="nav-tab-wrapper">
				<?php foreach ( $tabs as $option_key => $tab_title ) : ?>
					<a class="nav-tab<?php if ( isset( $_GET['page'] ) && $option_key === $_GET['page'] ) : ?> nav-tab-active<?php endif; ?>" href="<?php menu_page_url( $option_key ); ?>"><?php echo wp_kses_post( $tab_title ); ?></a>
				<?php endforeach; ?>
			</h2>
			<form class="cmb-form" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>" method="POST" id="<?php echo $cmb_options->cmb->cmb_id; ?>" enctype="multipart/form-data" encoding="multipart/form-data">
				<input type="hidden" name="action" value="<?php echo esc_attr( $cmb_options->option_key ); ?>">
				<?php $cmb_options->options_page_metabox(); ?>
				<?php submit_button( esc_attr( $cmb_options->cmb->prop( 'save_button' ) ), 'primary', 'submit-cmb' ); ?>
			</form>
		</div>
		<?php
	}
}

/**
 * Gets navigation tabs array for CMB2 options pages which share the given
 * display_cb param.
 *
 * @param CMB2_Options_Hookup $cmb_options The CMB2_Options_Hookup object.
 *
 * @return array Array of tab information.
 */
if( ! function_exists( 'wg_options_tabs' ) ) {
	function wg_options_tabs( $cmb_options ) {
		
		$tab_group = $cmb_options->cmb->prop( 'tab_group' );
		$tabs      = array();

		foreach ( CMB2_Boxes::get_all() as $cmb_id => $cmb ) {
			if ( $tab_group === $cmb->prop( 'tab_group' ) ) {
				$tabs[ $cmb->options_page_keys()[0] ] = $cmb->prop( 'tab_title' )
					? $cmb->prop( 'tab_title' )
					: $cmb->prop( 'title' );
			}
		}
		
		return $tabs;
	}
}

/**
 * Wrapper function around cmb2_get_option
 * @since  0.1.0
 * @param  string $key     Options array key
 * @param  mixed  $default Optional default value
 * @return mixed           Option value
 */
if( ! function_exists( 'wg_get_option' ) ) {
	function wg_get_option( $group='', $key = '', $default = false ) {
		if ( function_exists( 'cmb2_get_option' ) ) {
			// Use cmb2_get_option as it passes through some key filters.
			return cmb2_get_option( $group, $key, $default );
		}
		// Fallback to get_option if CMB2 is not loaded yet.
		$opts = get_option( $group, $default );
		$val = $default;
		if ( 'all' == $key ) {
			$val = $opts;
		} elseif ( is_array( $opts ) && array_key_exists( $key, $opts ) && false !== $opts[ $key ] ) {
			$val = $opts[ $key ];
		}
		return $val;
	}
}

/**
 * Wrapper function around cmb2_update_option
 * @since  0.1.0
 * @param  string $key     Options array key
 * @param  mixed  $default Optional default value
 * @return mixed           Option value
 */
if( ! function_exists( 'wg_update_option' ) ) {
	function wg_update_option( $group='', $key = '', $new_value ) {
		if ( function_exists( 'cmb2_update_option' ) ) {
			// Use cmb2_get_option as it passes through some key filters.
			return cmb2_update_option( $group, $key, $new_value );
		}
		// Fallback to update_option if CMB2 is not loaded yet.
		$opts = update_option( $group, $new_value );
			
	}
}