<?php
/**
 * Wonder Grid MetaBox
 *
 * @package Wonder Grid
 * @since   1.0.0
 */

defined( 'ABSPATH' ) || exit;

function wonder_grid_metabox() {
    $prefix = '_wonder_grid_';

    $form = new_cmb2_box( array(
        'id'            => $prefix . 'metabox',
        'title'         => esc_html__( 'Wonder Grid Settings', 'wonder-grid' ),
        'object_types'  => array( 'wonder-grid' ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
    ) );

    $form->add_field( array(
        'name' => esc_html__( 'Layout', 'wonder-grid' ),
        'id'   => $prefix . 'layout',
        'type' => 'select',
        'default' => apply_filters('wonder_grid/default_post_layout', 'two-columns'),
        'options' => array(
            'two-columns' => esc_html__( 'Two Columns', 'wonder-grid' ),
            'one-column' => esc_html__( 'One Column', 'wonder-grid' )
        )
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'description',
        'type'        => 'textarea',
        'name'        => esc_html__( 'Project Description', 'wonder-grid' ),
        'default'     => ''
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'client_name',
        'type'        => 'text',
        'name'        => esc_html__( 'Client', 'wonder-grid' ),
        'default'     => ''
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'skills_needed',
        'type'        => 'text',
        'name'        => esc_html__( 'Skills Needed', 'wonder-grid' ),
        'default'     => ''
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'finish_date',
        'type'        => 'text_date',
        'name'        => esc_html__( 'Finish Date', 'wonder-grid' ),
        'default'     => ''
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'project_url',
        'type'        => 'text_url',
        'name'        => esc_html__( 'Project URL', 'wonder-grid' ),
        'description' => esc_html__( 'Don\'t forget http:// or https://' , 'wonder-grid' ),
        'default'     => ''
    ) );

    $form->add_field( array(
        'name' => esc_html__( 'Media Type', 'wonder-grid' ),
        'description' => esc_html__( 'If you select Custom Content, then you can use content editor or page builder to custom the content.' , 'wonder-grid' ),
        'id'   => $prefix . 'media_type',
        'type' => 'select',
        'default' => 'images',
        'options' => array(
            'images' => esc_html__( 'Images', 'wonder-grid' ),
            'video' => esc_html__( 'Video', 'wonder-grid' ),
            'audio' => esc_html__( 'Audio', 'wonder-grid' ),
            'content' => esc_html__( 'Custom Content', 'wonder-grid' ),
        )
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'images',
        'type'        => 'file_list',
        'name'        => esc_html__( 'Upload Images', 'wonder-grid' ),
        'query_args'  => array( 'type' => 'image' ),
        'attributes'  => array(
            'data-conditional-id' => $prefix . 'media_type',
            'data-conditional-value' => 'images'
        )
    ) );

    $form->add_field( array(
        'name' => esc_html__( 'Images Layout', 'wonder-grid' ),
        'id'   => $prefix . 'images_layout',
        'type' => 'select',
        'default' => 'vertical',
        'options' => array(
            'vertical' => esc_html__( 'Vertical', 'wonder-grid' ),
            'slider' => esc_html__( 'Slider', 'wonder-grid' )
        ),
        'attributes'  => array(
            'data-conditional-id' => $prefix . 'media_type',
            'data-conditional-value' => 'images'
        )
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'video_url',
        'type'        => 'text_url',
        'name'        => esc_html__( 'Youtube/Vimeo URL', 'wonder-grid' ),
        'description' => esc_html__( 'Only support Youtube and Vimeo video, just paste the URL here, e.g. https://vimeo.com/xxxxx', 'wonder-grid' ),
        'attributes'  => array(
            'data-conditional-id' => $prefix . 'media_type',
            'data-conditional-value' => 'video'
        ),
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'audio_url',
        'type'        => 'text_url',
        'name'        => esc_html__( 'SoundCloud URL', 'wonder-grid' ),
        'description' => esc_html__( 'Only support SoundCloud Player, just paste the URL here, e.g. https://soundcloud.com/liltjay/20-20', 'wonder-grid' ),
        'attributes'  => array(
            'data-conditional-id' => $prefix . 'media_type',
            'data-conditional-value' => 'audio'
        ),
    ) );
}

add_action('cmb2_admin_init', 'wonder_grid_metabox' );
