<?php
/**
 * Template Name: Wonder Grid Page Template
 * If you want to override this template by your custom template in the theme folder,
 * just create the 'wonder-grid' folder in the theme folder,
 * then, copy this file to wonder-grid folder.
 * @version 1.0.0
 * @package Wonder Grid
 */

get_header();

  /**
   * Hooked Function: wg_wrapper_start
   * @see includes/functions.php
   */
   do_action( 'wonder_grid/grid_template_wrapper_start' );
?>

<?php while ( have_posts() ) : the_post(); ?>
<div class="wonder-grid-tax-title">
	<h1 itemprop="name" class="title"><?php the_title(); ?></h1>
	<div class="desc"><?php the_content(); ?></div>

  <?php
    /**
     * Taxonomy Filter
     */
     wg_taxonomy_filter( get_the_ID(), $GLOBALS['Wonder_Grid']->page_setting( 'page_types' ), $GLOBALS['Wonder_Grid']->page_setting( 'page_filter' ) );
  ?>
</div>
<?php endwhile; ?>

<?php do_action( 'wonder_grid/before_grid_container' ); ?>

<div class="wonder-grid" data-infinite="<?php echo $GLOBALS['Wonder_Grid']->page_setting( 'page_infinite' ); ?>">

  <div id="wg-grid-<?php the_ID(); ?>" data-id="<?php the_ID(); ?>" class="wonder-grid-container <?php echo 'wg-grid-columns-' . $GLOBALS['Wonder_Grid']->page_setting( 'page_columns' ); ?>">

  	<?php   
      if( ! is_front_page() ){
        $paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
      }else{		       
        $paged = get_query_var( 'page' ) ? get_query_var( 'page' ) : 1;
      }

      $paging = 'wg-paged';
      $paged = isset( $_GET[$paging] ) ? esc_attr( $_GET[$paging] ) : 1;
      $pagination_base = add_query_arg( $paging, '%#%' );

      $types = $GLOBALS['Wonder_Grid']->page_setting( 'page_types' );

      $params = array(
        'posts_per_page' => get_option( 'posts_per_page' ), 
        'post_type'      => 'wonder-grid',
        'orderby'        => $GLOBALS['Wonder_Grid']->page_setting( 'page_orderby' ),
        'order'          => $GLOBALS['Wonder_Grid']->page_setting( 'page_order' ),
        'paged'          => esc_attr( $paged ),
      );

      if( isset( $types ) && count( $types ) > 1 ) {
         $params['tax_query'] = array(
            array(
              'taxonomy' => 'wonder-grid-type',
              'field' => 'slug',
              'terms' => $types,
              'include_children' => true
            )
         );
      }

      $project_query = new WP_Query( $params ); 

  		if ( $project_query->have_posts() ) : 
  	?>

  		<?php
        $args = array( 
          'title_position' => $GLOBALS['Wonder_Grid']->page_setting( 'page_title_position' ),
          'hover_animation' => $GLOBALS['Wonder_Grid']->page_setting( 'page_hover_animation' ),
          'columns' => $GLOBALS['Wonder_Grid']->page_setting( 'page_columns' )
        );
  			
        while ( $project_query->have_posts() ) : 
  				$project_query->the_post(); 
  				/**
  				 * Hooked Function: wg_grid_item
  				 * @see includes/functions.php
  				 */
  				do_action( 'wonder_grid/grid_items', $args );
  			endwhile;
  			wp_reset_postdata(); 
  	  ?>

      <?php else: ?>

      	<p><?php esc_html_e( 'No project found.', 'wonder-grid' ); ?></p>

      <?php endif;?>

  </div>

  <div class="wonder-grid-pagenavi">
   <?php 
     if( $GLOBALS['Wonder_Grid']->page_setting( 'page_pagination' ) === 'yes' ) {
       echo paginate_links( array(
          'type'      => '',
          'base'      => $pagination_base,
          'format'    => '?'. $paging .'=%#%',
          'current'   => max( 1, $project_query->get('paged') ),
          'total'     => $project_query->max_num_pages
       ) ); 
     }
   ?>
  </div>

</div>

<?php do_action( 'wonder_grid/after_grid_container' );  ?>

<?php
  /**
   * Hooked Function: wg_wrapper_close
   * @see includes/functions.php
   */
   do_action( 'wonder_grid/grid_template_wrapper_close' );

get_footer();